pub enum MessageTone {
Beep,
None,
}Expand description
The cue a message node plays between its prompt and the start of recording.
JSON schema
{
"description": "The cue a message node plays between its prompt and the start of recording.",
"type": "string",
"enum": [
"beep",
"none"
]
}Variants